@@ -8,5 +8,5 @@
 
 domain=redturtle.chefcookie
 
-i18ndude rebuild-pot --pot $domain.pot --create $domain ../
+i18ndude rebuild-pot --pot $domain.pot --merge manual.pot --create $domain ../
 i18ndude sync --pot $domain.pot */LC_MESSAGES/$domain.po
